@@ -35,7 +35,7 @@
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2019 LE GARREC Vincent <legarrec.vincent@gmail.com>
-// Copyright (C) 2021 Oliver Sander <oliver.sander@tu-dresden.de>
+// Copyright (C) 2021, 2022 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -197,79 +197,61 @@ const GooString *GfxFontLoc::pathAsGooString() const
 // GfxFont
 //------------------------------------------------------------------------
 
-GfxFont *GfxFont::makeFont(XRef *xref, const char *tagA, Ref idA, Dict *fontDict)
+std::unique_ptr<GfxFont> GfxFont::makeFont(XRef *xref, const char *tagA, Ref idA, Dict *fontDict)
 {
-    GooString *nameA;
+    std::optional<std::string> name;
     Ref embFontIDA;
     GfxFontType typeA;
-    GfxFont *font;
 
     // get base font name
-    nameA = nullptr;
     Object obj1 = fontDict->lookup("BaseFont");
     if (obj1.isName()) {
-        nameA = new GooString(obj1.getName());
+        name = obj1.getName();
     }
 
     // get embedded font ID and font type
     typeA = getFontType(xref, fontDict, &embFontIDA);
 
     // create the font object
-    font = nullptr;
+    GfxFont *font;
     if (typeA < fontCIDType0) {
-        font = new Gfx8BitFont(xref, tagA, idA, nameA, typeA, embFontIDA, fontDict);
+        font = new Gfx8BitFont(xref, tagA, idA, std::move(name), typeA, embFontIDA, fontDict);
     } else {
-        font = new GfxCIDFont(xref, tagA, idA, nameA, typeA, embFontIDA, fontDict);
+        font = new GfxCIDFont(xref, tagA, idA, std::move(name), typeA, embFontIDA, fontDict);
     }
 
-    return font;
+    return std::unique_ptr<GfxFont>(font);
 }
 
-GfxFont::GfxFont(const char *tagA, Ref idA, const GooString *nameA, GfxFontType typeA, Ref embFontIDA) : tag(tagA), id(idA), type(typeA)
+GfxFont::GfxFont(const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA) : tag(tagA), id(idA), name(std::move(nameA)), type(typeA)
 {
     ok = false;
-    name = nameA;
     embFontID = embFontIDA;
     embFontName = nullptr;
     family = nullptr;
     stretch = StretchNotDefined;
     weight = WeightNotDefined;
-    refCnt = 1;
     hasToUnicode = false;
 }
 
 GfxFont::~GfxFont()
 {
     delete family;
-    if (name) {
-        delete name;
-    }
     if (embFontName) {
         delete embFontName;
     }
 }
 
-void GfxFont::incRefCnt()
-{
-    refCnt++;
-}
-
-void GfxFont::decRefCnt()
-{
-    if (--refCnt == 0)
-        delete this;
-}
-
 bool GfxFont::isSubset() const
 {
     if (name) {
-        int i;
-        for (i = 0; i < name->getLength(); ++i) {
-            if (name->getChar(i) < 'A' || name->getChar(i) > 'Z') {
+        unsigned int i;
+        for (i = 0; i < name->size(); ++i) {
+            if ((*name)[i] < 'A' || (*name)[i] > 'Z') {
                 break;
             }
         }
-        return i == 6 && name->getLength() > 7 && name->getChar(6) == '+';
+        return i == 6 && name->size() > 7 && (*name)[6] == '+';
     }
     return false;
 }
@@ -281,10 +263,10 @@ std::string GfxFont::getNameWithoutSubsetTag() const
     }
 
     if (!isSubset()) {
-        return name->toStr();
+        return *name;
     }
 
-    return name->toStr().substr(7);
+    return name->substr(7);
 }
 
 // This function extracts three pieces of information:
@@ -503,57 +485,60 @@ void GfxFont::readFontDescriptor(XRef *xref, Dict *fontDict)
 
         // get family
         obj2 = obj1.dictLookup("FontFamily");
-        if (obj2.isString())
+        if (obj2.isString()) {
             family = new GooString(obj2.getString());
+        }
 
         // get stretch
         obj2 = obj1.dictLookup("FontStretch");
         if (obj2.isName()) {
-            if (strcmp(obj2.getName(), "UltraCondensed") == 0)
+            if (strcmp(obj2.getName(), "UltraCondensed") == 0) {
                 stretch = UltraCondensed;
-            else if (strcmp(obj2.getName(), "ExtraCondensed") == 0)
+            } else if (strcmp(obj2.getName(), "ExtraCondensed") == 0) {
                 stretch = ExtraCondensed;
-            else if (strcmp(obj2.getName(), "Condensed") == 0)
+            } else if (strcmp(obj2.getName(), "Condensed") == 0) {
                 stretch = Condensed;
-            else if (strcmp(obj2.getName(), "SemiCondensed") == 0)
+            } else if (strcmp(obj2.getName(), "SemiCondensed") == 0) {
                 stretch = SemiCondensed;
-            else if (strcmp(obj2.getName(), "Normal") == 0)
+            } else if (strcmp(obj2.getName(), "Normal") == 0) {
                 stretch = Normal;
-            else if (strcmp(obj2.getName(), "SemiExpanded") == 0)
+            } else if (strcmp(obj2.getName(), "SemiExpanded") == 0) {
                 stretch = SemiExpanded;
-            else if (strcmp(obj2.getName(), "Expanded") == 0)
+            } else if (strcmp(obj2.getName(), "Expanded") == 0) {
                 stretch = Expanded;
-            else if (strcmp(obj2.getName(), "ExtraExpanded") == 0)
+            } else if (strcmp(obj2.getName(), "ExtraExpanded") == 0) {
                 stretch = ExtraExpanded;
-            else if (strcmp(obj2.getName(), "UltraExpanded") == 0)
+            } else if (strcmp(obj2.getName(), "UltraExpanded") == 0) {
                 stretch = UltraExpanded;
-            else
+            } else {
                 error(errSyntaxWarning, -1, "Invalid Font Stretch");
+            }
         }
 
         // get weight
         obj2 = obj1.dictLookup("FontWeight");
         if (obj2.isNum()) {
-            if (obj2.getNum() == 100)
+            if (obj2.getNum() == 100) {
                 weight = W100;
-            else if (obj2.getNum() == 200)
+            } else if (obj2.getNum() == 200) {
                 weight = W200;
-            else if (obj2.getNum() == 300)
+            } else if (obj2.getNum() == 300) {
                 weight = W300;
-            else if (obj2.getNum() == 400)
+            } else if (obj2.getNum() == 400) {
                 weight = W400;
-            else if (obj2.getNum() == 500)
+            } else if (obj2.getNum() == 500) {
                 weight = W500;
-            else if (obj2.getNum() == 600)
+            } else if (obj2.getNum() == 600) {
                 weight = W600;
-            else if (obj2.getNum() == 700)
+            } else if (obj2.getNum() == 700) {
                 weight = W700;
-            else if (obj2.getNum() == 800)
+            } else if (obj2.getNum() == 800) {
                 weight = W800;
-            else if (obj2.getNum() == 900)
+            } else if (obj2.getNum() == 900) {
                 weight = W900;
-            else
+            } else {
                 error(errSyntaxWarning, -1, "Invalid Font Weight");
+            }
         }
 
         // look for MissingWidth
@@ -672,7 +657,7 @@ std::optional<GfxFontLoc> GfxFont::locateFont(XRef *xref, PSOutputDev *ps)
                 fontLoc.locType = gfxFontLocEmbedded;
                 fontLoc.fontType = type;
                 fontLoc.embFontID = embFontID;
-                return std::move(fontLoc); // std::move only required to please g++-7
+                return fontLoc;
             }
         }
     }
@@ -682,8 +667,8 @@ std::optional<GfxFontLoc> GfxFont::locateFont(XRef *xref, PSOutputDev *ps)
         GfxFontLoc fontLoc;
         fontLoc.locType = gfxFontLocResident;
         fontLoc.fontType = fontType1;
-        fontLoc.setPath(name->copy());
-        return std::move(fontLoc); // std::move only required to please g++-7
+        fontLoc.path = *name;
+        return fontLoc;
     }
 
     //----- PS resident Base-14 font
@@ -692,11 +677,11 @@ std::optional<GfxFontLoc> GfxFont::locateFont(XRef *xref, PSOutputDev *ps)
         fontLoc.locType = gfxFontLocResident;
         fontLoc.fontType = fontType1;
         fontLoc.path = ((Gfx8BitFont *)this)->base14->base14Name;
-        return std::move(fontLoc); // std::move only required to please g++-7
+        return fontLoc;
     }
 
     //----- external font file (fontFile, fontDir)
-    if (name && (path = globalParams->findFontFile(name))) {
+    if (name && (path = globalParams->findFontFile(*name))) {
         if (std::optional<GfxFontLoc> fontLoc = getExternalFont(path, isCIDFont())) {
             return fontLoc;
         }
@@ -723,7 +708,7 @@ std::optional<GfxFontLoc> GfxFont::locateFont(XRef *xref, PSOutputDev *ps)
                 fontLoc.fontType = fontCIDType2;
                 fontLoc.setPath(path);
                 fontLoc.fontNum = fontNum;
-                return std::move(fontLoc); // std::move only required to please g++-7
+                return fontLoc;
             }
         } else {
             GfxFontLoc fontLoc;
@@ -735,7 +720,7 @@ std::optional<GfxFontLoc> GfxFont::locateFont(XRef *xref, PSOutputDev *ps)
                 fontLoc.fontType = fontType1;
                 fontLoc.fontNum = fontNum;
             }
-            return std::move(fontLoc); // std::move only required to please g++-7
+            return fontLoc;
         }
         delete path;
     }
@@ -756,21 +741,21 @@ std::optional<GfxFontLoc> GfxFont::locateFont(XRef *xref, PSOutputDev *ps)
         if (isItalic()) {
             substIdx += 1;
         }
-        GooString substName(base14SubstFonts[substIdx]);
+        const std::string substName = base14SubstFonts[substIdx];
         if (ps) {
             error(errSyntaxWarning, -1, "Substituting font '{0:s}' for '{1:s}'", base14SubstFonts[substIdx], name ? name->c_str() : "null");
             GfxFontLoc fontLoc;
             fontLoc.locType = gfxFontLocResident;
             fontLoc.fontType = fontType1;
-            fontLoc.path = substName.toStr();
+            fontLoc.path = substName;
             fontLoc.substIdx = substIdx;
-            return std::move(fontLoc); // std::move only required to please g++-7
+            return fontLoc;
         } else {
-            path = globalParams->findFontFile(&substName);
+            path = globalParams->findFontFile(substName);
             if (path) {
                 if (std::optional<GfxFontLoc> fontLoc = getExternalFont(path, false)) {
                     error(errSyntaxWarning, -1, "Substituting font '{0:s}' for '{1:s}'", base14SubstFonts[substIdx], name ? name->c_str() : "");
-                    name = new GooString(base14SubstFonts[substIdx]);
+                    name = base14SubstFonts[substIdx];
                     fontLoc->substIdx = substIdx;
                     return fontLoc;
                 }
@@ -785,17 +770,6 @@ std::optional<GfxFontLoc> GfxFont::locateFont(XRef *xref, PSOutputDev *ps)
     return std::nullopt;
 }
 
-std::optional<GfxFontLoc> GfxFont::locateBase14Font(const GooString *base14Name)
-{
-    GooString *path;
-
-    path = globalParams->findFontFile(base14Name);
-    if (!path) {
-        return std::nullopt;
-    }
-    return getExternalFont(path, false);
-}
-
 std::optional<GfxFontLoc> GfxFont::getExternalFont(GooString *path, bool cid)
 {
     FoFiIdentifierType fft;
@@ -837,12 +811,11 @@ std::optional<GfxFontLoc> GfxFont::getExternalFont(GooString *path, bool cid)
     fontLoc.locType = gfxFontLocExternal;
     fontLoc.fontType = fontType;
     fontLoc.setPath(path);
-    return std::move(fontLoc); // std::move only required to please g++-7
+    return fontLoc;
 }
 
-char *GfxFont::readEmbFontFile(XRef *xref, int *len)
+std::optional<std::vector<unsigned char>> GfxFont::readEmbFontFile(XRef *xref)
 {
-    char *buf;
     Stream *str;
 
     Object obj1(embFontID);
@@ -850,12 +823,11 @@ char *GfxFont::readEmbFontFile(XRef *xref, int *len)
     if (!obj2.isStream()) {
         error(errSyntaxError, -1, "Embedded font file is not a stream");
         embFontID = Ref::INVALID();
-        *len = 0;
-        return nullptr;
+        return {};
     }
     str = obj2.getStream();
 
-    buf = (char *)str->toUnsignedChars(len);
+    std::vector<unsigned char> buf = str->toUnsignedChars();
     str->close();
 
     return buf;
@@ -897,8 +869,9 @@ static bool parseNumericName(const char *s, bool hex, unsigned int *u)
         int n = 0;
 
         // Get string length while ignoring junk at end.
-        while (isalnum(s[n]))
+        while (isalnum(s[n])) {
             ++n;
+        }
 
         // Only 2 hex characters with optional leading alpha is allowed.
         if (n == 3 && isalpha(*s)) {
@@ -908,22 +881,26 @@ static bool parseNumericName(const char *s, bool hex, unsigned int *u)
         }
     } else {
         // Strip up to two alpha characters.
-        for (int i = 0; i < 2 && isalpha(*s); ++i)
+        for (int i = 0; i < 2 && isalpha(*s); ++i) {
             ++s;
+        }
     }
 
     int v = strtol(s, &endptr, hex ? 16 : 10);
 
-    if (endptr == s)
+    if (endptr == s) {
         return false;
+    }
 
     // Skip trailing junk characters.
-    while (*endptr != '\0' && !isalnum(*endptr))
+    while (*endptr != '\0' && !isalnum(*endptr)) {
         ++endptr;
+    }
 
     if (*endptr == '\0') {
-        if (u)
+        if (u) {
             *u = v;
+        }
         return true;
     }
     return false;
@@ -949,12 +926,14 @@ static bool testForNumericNames(Dict *fontDict, bool hex)
         Object obj = diff.arrayGet(i);
         if (obj.isInt()) {
             // All sequences must start between character codes 0 and 5.
-            if (obj.getInt() > 5)
+            if (obj.getInt() > 5) {
                 numeric = false;
+            }
         } else if (obj.isName()) {
             // All character names must successfully parse.
-            if (!parseNumericName(obj.getName(), hex, nullptr))
+            if (!parseNumericName(obj.getName(), hex, nullptr)) {
                 numeric = false;
+            }
         } else {
             numeric = false;
         }
@@ -963,13 +942,11 @@ static bool testForNumericNames(Dict *fontDict, bool hex)
     return numeric;
 }
 
-Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict) : GfxFont(tagA, idA, nameA, typeA, embFontIDA)
+Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict) : GfxFont(tagA, idA, std::move(nameA), typeA, embFontIDA)
 {
-    GooString *name2;
     const BuiltinFont *builtinFont;
     const char **baseEnc;
     bool baseEncFromFontFile;
-    char *buf;
     int len;
     FoFiType1 *ffT1;
     FoFiType1C *ffT1C;
@@ -982,20 +959,19 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
     int firstChar, lastChar;
     unsigned short w;
     Object obj1;
-    int n, i, a, b, m;
+    int n, a, b, m;
 
-    refCnt = 1;
     ctu = nullptr;
 
     // do font name substitution for various aliases of the Base 14 font
     // names
     base14 = nullptr;
     if (name) {
-        name2 = name->copy();
-        i = 0;
-        while (i < name2->getLength()) {
-            if (name2->getChar(i) == ' ') {
-                name2->del(i);
+        std::string name2 = *name;
+        size_t i = 0;
+        while (i < name2.size()) {
+            if (name2[i] == ' ') {
+                name2.erase(i, 1);
             } else {
                 ++i;
             }
@@ -1005,16 +981,15 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
         // invariant: base14FontMap[a].altName <= name2 < base14FontMap[b].altName
         while (b - a > 1) {
             m = (a + b) / 2;
-            if (name2->cmp(base14FontMap[m].altName) >= 0) {
+            if (name2.compare(base14FontMap[m].altName) >= 0) {
                 a = m;
             } else {
                 b = m;
             }
         }
-        if (!name2->cmp(base14FontMap[a].altName)) {
+        if (name2 == base14FontMap[a].altName) {
             base14 = &base14FontMap[a];
         }
-        delete name2;
     }
 
     // is it a built-in font?
@@ -1061,7 +1036,7 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
     fontMat[1] = fontMat[2] = fontMat[4] = fontMat[5] = 0;
     obj1 = fontDict->lookup("FontMatrix");
     if (obj1.isArray()) {
-        for (i = 0; i < 6 && i < obj1.arrayGetLength(); ++i) {
+        for (int i = 0; i < 6 && i < obj1.arrayGetLength(); ++i) {
             Object obj2 = obj1.arrayGet(i);
             if (obj2.isNum()) {
                 fontMat[i] = obj2.getNum();
@@ -1073,7 +1048,7 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
     if (type == fontType3) {
         obj1 = fontDict->lookup("FontBBox");
         if (obj1.isArray()) {
-            for (i = 0; i < 4 && i < obj1.arrayGetLength(); ++i) {
+            for (int i = 0; i < 4 && i < obj1.arrayGetLength(); ++i) {
                 Object obj2 = obj1.arrayGet(i);
                 if (obj2.isNum()) {
                     fontBBox[i] = obj2.getNum();
@@ -1141,10 +1116,10 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
     // TrueType font is a losing proposition)
     ffT1 = nullptr;
     ffT1C = nullptr;
-    buf = nullptr;
     if (type == fontType1 && embFontID != Ref::INVALID()) {
-        if ((buf = readEmbFontFile(xref, &len))) {
-            if ((ffT1 = FoFiType1::make(buf, len))) {
+        const std::optional<std::vector<unsigned char>> buf = readEmbFontFile(xref);
+        if (buf) {
+            if ((ffT1 = FoFiType1::make(buf->data(), buf->size()))) {
                 if (ffT1->getName()) {
                     if (embFontName) {
                         delete embFontName;
@@ -1156,11 +1131,11 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
                     baseEncFromFontFile = true;
                 }
             }
-            gfree(buf);
         }
     } else if (type == fontType1C && embFontID != Ref::INVALID()) {
-        if ((buf = readEmbFontFile(xref, &len))) {
-            if ((ffT1C = FoFiType1C::make(buf, len))) {
+        const std::optional<std::vector<unsigned char>> buf = readEmbFontFile(xref);
+        if (buf) {
+            if ((ffT1C = FoFiType1C::make(buf->data(), buf->size()))) {
                 if (ffT1C->getName()) {
                     if (embFontName) {
                         delete embFontName;
@@ -1172,7 +1147,6 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
                     baseEncFromFontFile = true;
                 }
             }
-            gfree(buf);
         }
     }
 
@@ -1205,7 +1179,7 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
     }
 
     // copy the base encoding
-    for (i = 0; i < 256; ++i) {
+    for (int i = 0; i < 256; ++i) {
         enc[i] = (char *)baseEnc[i];
         if ((encFree[i] = baseEncFromFontFile) && enc[i]) {
             enc[i] = copyString(baseEnc[i]);
@@ -1217,7 +1191,7 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
     // the accents in the encoding), so we fill in any gaps from
     // StandardEncoding
     if (type == fontType1C && embFontID != Ref::INVALID() && baseEncFromFontFile) {
-        for (i = 0; i < 256; ++i) {
+        for (int i = 0; i < 256; ++i) {
             if (!enc[i] && standardEncoding[i]) {
                 enc[i] = (char *)standardEncoding[i];
                 encFree[i] = false;
@@ -1232,7 +1206,7 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
             encodingName = "Custom";
             hasEncoding = true;
             int code = 0;
-            for (i = 0; i < obj2.arrayGetLength(); ++i) {
+            for (int i = 0; i < obj2.arrayGetLength(); ++i) {
                 Object obj3 = obj2.arrayGet(i);
                 if (obj3.isInt()) {
                     code = obj3.getInt();
@@ -1258,7 +1232,7 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
 
     // pass 1: use the name-to-Unicode mapping table
     missing = hex = false;
-    bool isZapfDingbats = name && name->endsWith("ZapfDingbats");
+    bool isZapfDingbats = name && GooString::endsWith(*name, "ZapfDingbats");
     for (int code = 0; code < 256; ++code) {
         if ((charName = enc[code])) {
             if (isZapfDingbats) {
@@ -1296,8 +1270,9 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
     for (int code = 0; code < 256; ++code) {
         if (unicodeIsAlphabeticPresentationForm(toUnicode[code])) {
             Unicode *normalized = unicodeNormalizeNFKC(&toUnicode[code], 1, &len, nullptr);
-            if (len > 1)
+            if (len > 1) {
                 ctu->setMapping((CharCode)code, normalized, len);
+            }
             gfree(normalized);
         }
     }
@@ -1390,6 +1365,7 @@ Gfx8BitFont::Gfx8BitFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA
         // this is technically an error -- the Widths entry is required
         // for all but the Base-14 fonts -- but certain PDF generators
         // apparently don't include widths for Arial and TimesNewRoman
+        int i;
         if (isFixedWidth()) {
             i = 0;
         } else if (isSerif()) {
@@ -1467,17 +1443,19 @@ static int parseCharName(char *charName, Unicode *uBuf, int uLen, bool names, bo
         int n = 0, m;
         lig_part = lig_copy = copyString(charName);
         do {
-            if ((lig_end = strchr(lig_part, '_')))
+            if ((lig_end = strchr(lig_part, '_'))) {
                 *lig_end = '\0';
+            }
             if (lig_part[0] != '\0') {
                 bool namesRecurse = true, ligaturesRecurse = false;
-                if ((m = parseCharName(lig_part, uBuf + n, uLen - n, namesRecurse, ligaturesRecurse, numeric, hex, variants)))
+                if ((m = parseCharName(lig_part, uBuf + n, uLen - n, namesRecurse, ligaturesRecurse, numeric, hex, variants))) {
                     n += m;
-                else
+                } else {
                     error(errSyntaxWarning, -1,
                           "Could not parse ligature component \"{0:s}\" of \"{1:s}\" in "
                           "parseCharName",
                           lig_part, charName);
+                }
             }
             if (lig_end) {
                 lig_part = lig_end + 1;
@@ -1537,8 +1515,9 @@ static int parseCharName(char *charName, Unicode *uBuf, int uLen, bool names, bo
     }
     // Not in Adobe Glyph Mapping convention: look for names like xx
     // or Axx and parse for hex or decimal values.
-    if (numeric && parseNumericName(charName, hex, uBuf))
+    if (numeric && parseNumericName(charName, hex, uBuf)) {
         return 1;
+    }
     // 3.5. otherwise, map the component to the empty string
     return 0;
 }
@@ -1654,14 +1633,15 @@ int *Gfx8BitFont::getCodeToGIDMap(FoFiTrueType *ff)
     } else if (useUnicode) {
         const Unicode *uAux;
         for (i = 0; i < 256; ++i) {
-            if (((charName = enc[i]) && (u = globalParams->mapNameToUnicodeAll(charName))))
+            if (((charName = enc[i]) && (u = globalParams->mapNameToUnicodeAll(charName)))) {
                 map[i] = ff->mapCodeToGID(cmap, u);
-            else {
+            } else {
                 n = ctu->mapToUnicode((CharCode)i, &uAux);
-                if (n > 0)
+                if (n > 0) {
                     map[i] = ff->mapCodeToGID(cmap, uAux[0]);
-                else
+                } else {
                     map[i] = -1;
+                }
             }
         }
 
@@ -1727,7 +1707,7 @@ struct cmpWidthExcepVFunctor
     bool operator()(const GfxFontCIDWidthExcepV &w1, const GfxFontCIDWidthExcepV &w2) { return w1.first < w2.first; }
 };
 
-GfxCIDFont::GfxCIDFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict) : GfxFont(tagA, idA, nameA, typeA, embFontIDA)
+GfxCIDFont::GfxCIDFont(XRef *xref, const char *tagA, Ref idA, std::optional<std::string> &&nameA, GfxFontType typeA, Ref embFontIDA, Dict *fontDict) : GfxFont(tagA, idA, std::move(nameA), typeA, embFontIDA)
 {
     Dict *desFontDict;
     Object desFontDictObj;
@@ -1735,7 +1715,6 @@ GfxCIDFont::GfxCIDFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA,
     int c1, c2;
     int excepsSize;
 
-    refCnt = 1;
     ascent = 0.95;
     descent = -0.35;
     fontBBox[0] = fontBBox[1] = fontBBox[2] = fontBBox[3] = 0;
@@ -1835,7 +1814,7 @@ GfxCIDFont::GfxCIDFont(XRef *xref, const char *tagA, Ref idA, GooString *nameA,
     obj1 = desFontDict->lookup("CIDToGIDMap");
     if (obj1.isStream()) {
         cidToGIDLen = 0;
-        int i = 64;
+        unsigned int i = 64;
         cidToGID = (int *)gmallocn(i, sizeof(int));
         obj1.streamReset();
         while ((c1 = obj1.streamGetChar()) != EOF && (c2 = obj1.streamGetChar()) != EOF) {
@@ -2061,7 +2040,7 @@ int GfxCIDFont::getNextChar(const char *s, int len, CharCode *code, Unicode cons
     return n;
 }
 
-int GfxCIDFont::getWMode()
+int GfxCIDFont::getWMode() const
 {
     return cMap ? cMap->getWMode() : 0;
 }
@@ -2081,8 +2060,9 @@ int GfxCIDFont::mapCodeToGID(FoFiTrueType *ff, int cmapi, Unicode unicode, bool
     unsigned short gid = ff->mapCodeToGID(cmapi, unicode);
     if (wmode) {
         unsigned short vgid = ff->mapToVertGID(gid);
-        if (vgid != 0)
+        if (vgid != 0) {
             gid = vgid;
+        }
     }
     return gid;
 }
@@ -2154,12 +2134,14 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *codeToGIDLen)
     Ref embID;
 
     *codeToGIDLen = 0;
-    if (!ctu || !getCollection())
+    if (!ctu || !getCollection()) {
         return nullptr;
+    }
 
     if (getEmbeddedFontID(&embID)) {
-        if (getCollection()->cmp("Adobe-Identity") == 0)
+        if (getCollection()->cmp("Adobe-Identity") == 0) {
             return nullptr;
+        }
 
         /* if this font is embedded font,
          * CIDToGIDMap should be embedded in PDF file
@@ -2186,8 +2168,9 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *codeToGIDLen)
             cmap = i;
         }
     }
-    if (cmap < 0)
+    if (cmap < 0) {
         return nullptr;
+    }
 
     wmode = getWMode();
     for (lp = CMapList; lp->collection != nullptr; lp++) {
@@ -2236,7 +2219,7 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *codeToGIDLen)
         ff->setupGSUB(lp->scriptTag, lp->languageTag);
     } else {
         if (getCollection()->cmp("Adobe-Identity") == 0) {
-            error(errSyntaxError, -1, "non-embedded font using identity encoding: {0:t}", getName());
+            error(errSyntaxError, -1, "non-embedded font using identity encoding: {0:s}", name ? name->c_str() : "(null)");
         } else {
             error(errSyntaxError, -1, "Unknown character collection {0:t}\n", getCollection());
         }
@@ -2245,10 +2228,11 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *codeToGIDLen)
             for (cid = 0; cid < n; cid++) {
                 const Unicode *ucode;
 
-                if (ctu->mapToUnicode(cid, &ucode))
+                if (ctu->mapToUnicode(cid, &ucode)) {
                     humap[cid * N_UCS_CANDIDATES] = ucode[0];
-                else
+                } else {
                     humap[cid * N_UCS_CANDIDATES] = 0;
+                }
                 for (i = 1; i < N_UCS_CANDIDATES; i++) {
                     humap[cid * N_UCS_CANDIDATES + i] = 0;
                 }
@@ -2288,8 +2272,9 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *codeToGIDLen)
             /* special handling space characters */
             const unsigned long *p;
 
-            if (humap != nullptr)
+            if (humap != nullptr) {
                 unicode = humap[code];
+            }
             if (unicode != 0) {
                 /* check if code is space character , so map code to 0x0020 */
                 for (p = spaces; *p != 0; p++) {
@@ -2304,12 +2289,15 @@ int *GfxCIDFont::getCodeToGIDMap(FoFiTrueType *ff, int *codeToGIDLen)
         codeToGID[code] = gid;
     }
     *codeToGIDLen = n;
-    if (humap != nullptr)
+    if (humap != nullptr) {
         delete[] humap;
-    if (tumap != nullptr)
+    }
+    if (tumap != nullptr) {
         delete[] tumap;
-    if (vumap != nullptr)
+    }
+    if (vumap != nullptr) {
         delete[] vumap;
+    }
     return codeToGID;
 }
 
@@ -2353,12 +2341,10 @@ double GfxCIDFont::getWidth(char *s, int len) const
 
 GfxFontDict::GfxFontDict(XRef *xref, Ref *fontDictRef, Dict *fontDict)
 {
-    int i;
     Ref r;
 
-    numFonts = fontDict->getLength();
-    fonts = (GfxFont **)gmallocn(numFonts, sizeof(GfxFont *));
-    for (i = 0; i < numFonts; ++i) {
+    fonts.resize(fontDict->getLength());
+    for (std::size_t i = 0; i < fonts.size(); ++i) {
         const Object &obj1 = fontDict->getValNF(i);
         Object obj2 = obj1.fetch(xref);
         if (obj2.isDict()) {
@@ -2381,8 +2367,7 @@ GfxFontDict::GfxFontDict(XRef *xref, Ref *fontDictRef, Dict *fontDict)
                 // NULL and !isOk() so that when we do lookups
                 // we can tell the difference between a missing font
                 // and a font that is just !isOk()
-                fonts[i]->decRefCnt();
-                fonts[i] = nullptr;
+                fonts[i].reset();
             }
         } else {
             error(errSyntaxError, -1, "font resource is not a dictionary");
@@ -2391,25 +2376,11 @@ GfxFontDict::GfxFontDict(XRef *xref, Ref *fontDictRef, Dict *fontDict)
     }
 }
 
-GfxFontDict::~GfxFontDict()
+std::shared_ptr<GfxFont> GfxFontDict::lookup(const char *tag) const
 {
-    int i;
-
-    for (i = 0; i < numFonts; ++i) {
-        if (fonts[i]) {
-            fonts[i]->decRefCnt();
-        }
-    }
-    gfree(fonts);
-}
-
-GfxFont *GfxFontDict::lookup(const char *tag) const
-{
-    int i;
-
-    for (i = 0; i < numFonts; ++i) {
-        if (fonts[i] && fonts[i]->matches(tag)) {
-            return fonts[i];
+    for (const auto &font : fonts) {
+        if (font && font->matches(tag)) {
+            return font;
         }
     }
     return nullptr;
