@@ -16,6 +16,7 @@
 // Copyright 2020 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by Technische Universität Dresden
 // Copyright 2021 Theofilos Intzoglou <int.teo@gmail.com>
 // Copyright 2021 Marek Kasik <mkasik@redhat.com>
+// Copyright 2022 Erich E. Hoover <erich.e.hoover@gmail.com>
 //
 //========================================================================
 
@@ -525,7 +526,11 @@ std::string SignatureHandler::getSignerName()
 {
     char *commonName;
 
-    if (!CMSSignerInfo || !NSS_IsInitialized()) {
+    if (!NSS_IsInitialized()) {
+        return {};
+    }
+
+    if (!signing_cert && !CMSSignerInfo) {
         return {};
     }
 
@@ -538,6 +543,9 @@ std::string SignatureHandler::getSignerName()
     }
 
     commonName = CERT_GetCommonName(&signing_cert->subject);
+    if (!commonName) {
+        return {};
+    }
     std::string name(commonName);
     PORT_Free(commonName);
 
