@@ -232,30 +232,35 @@ void ImageOutputDev::listImage(GfxState *state, Object *ref, Stream *str, int wi
     double height2 = sqrt(mat[2] * mat[2] + mat[3] * mat[3]);
     double xppi = fabs(width * 72.0 / width2);
     double yppi = fabs(height * 72.0 / height2);
-    if (xppi < 1.0)
+    if (xppi < 1.0) {
         printf("%5.3f ", xppi);
-    else
+    } else {
         printf("%5.0f ", xppi);
-    if (yppi < 1.0)
+    }
+    if (yppi < 1.0) {
         printf("%5.3f ", yppi);
-    else
+    } else {
         printf("%5.0f ", yppi);
+    }
 
     Goffset embedSize = -1;
-    if (inlineImg)
+    if (inlineImg) {
         embedSize = getInlineImageLength(str, width, height, colorMap);
-    else
+    } else {
         embedSize = str->getBaseStream()->getLength();
+    }
 
     long long imageSize = 0;
-    if (colorMap && colorMap->isOk())
+    if (colorMap && colorMap->isOk()) {
         imageSize = ((long long)width * height * colorMap->getNumPixelComps() * colorMap->getBits()) / 8;
-    else
+    } else {
         imageSize = (long long)width * height / 8; // mask
+    }
 
     double ratio = -1.0;
-    if (imageSize > 0)
+    if (imageSize > 0) {
         ratio = 100.0 * embedSize / imageSize;
+    }
 
     if (embedSize < 0) {
         printf("   - ");
@@ -279,12 +284,13 @@ void ImageOutputDev::listImage(GfxState *state, Object *ref, Stream *str, int wi
         }
     }
 
-    if (ratio > 9.9)
+    if (ratio > 9.9) {
         printf(" %3.0f%%\n", ratio);
-    else if (ratio >= 0.0)
+    } else if (ratio >= 0.0) {
         printf(" %3.1f%%\n", ratio);
-    else
+    } else {
         printf("   - \n");
+    }
 
     ++imgNum;
 }
@@ -296,8 +302,9 @@ long ImageOutputDev::getInlineImageLength(Stream *str, int width, int height, Gf
     if (colorMap) {
         ImageStream *imgStr = new ImageStream(str, width, colorMap->getNumPixelComps(), colorMap->getBits());
         imgStr->reset();
-        for (int y = 0; y < height; y++)
+        for (int y = 0; y < height; y++) {
             imgStr->getLine();
+        }
 
         imgStr->close();
         delete imgStr;
@@ -305,16 +312,18 @@ long ImageOutputDev::getInlineImageLength(Stream *str, int width, int height, Gf
         str->reset();
         for (int y = 0; y < height; y++) {
             int size = (width + 7) / 8;
-            for (int x = 0; x < size; x++)
+            for (int x = 0; x < size; x++) {
                 str->getChar();
+            }
         }
     }
 
     EmbedStream *embedStr = (EmbedStream *)(str->getBaseStream());
     embedStr->rewind();
     len = 0;
-    while (embedStr->getChar() != EOF)
+    while (embedStr->getChar() != EOF) {
         len++;
+    }
 
     embedStr->restore();
 
@@ -339,8 +348,9 @@ void ImageOutputDev::writeRawImage(Stream *str, const char *ext)
     str->reset();
 
     // copy the stream
-    while ((c = str->getChar()) != EOF)
+    while ((c = str->getChar()) != EOF) {
         fputc(c, f);
+    }
 
     str->close();
     fclose(f);
@@ -374,8 +384,9 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
     }
 
     int pixelSize = sizeof(unsigned int);
-    if (format == imgRGB48)
+    if (format == imgRGB48) {
         pixelSize = 2 * sizeof(unsigned int);
+    }
 
     row = (unsigned char *)gmallocn_checkoverflow(width, pixelSize);
     if (!row) {
@@ -400,8 +411,9 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
     if (colorMap) {
         memset(zero, 0, sizeof(zero));
         colorMap->getGray(zero, &gray);
-        if (colToByte(gray) == 0)
+        if (colToByte(gray) == 0) {
             invert_bits = 0x00;
+        }
     }
 
     // for each line...
@@ -423,8 +435,9 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
                     *rowp++ = 0;
                 }
             }
-            if (writer)
+            if (writer) {
                 writer->writeRow(&row);
+            }
             break;
 
         case imgRGB48: {
@@ -443,8 +456,9 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
                     *rowp16++ = 0;
                 }
             }
-            if (writer)
+            if (writer) {
                 writer->writeRow(&row);
+            }
             break;
         }
 
@@ -466,8 +480,9 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
                     *rowp++ = 0;
                 }
             }
-            if (writer)
+            if (writer) {
                 writer->writeRow(&row);
+            }
             break;
 
         case imgGray:
@@ -482,16 +497,19 @@ void ImageOutputDev::writeImageFile(ImgWriter *writer, ImageFormat format, const
                     *rowp++ = 0;
                 }
             }
-            if (writer)
+            if (writer) {
                 writer->writeRow(&row);
+            }
             break;
 
         case imgMonochrome:
             int size = (width + 7) / 8;
-            for (int x = 0; x < size; x++)
+            for (int x = 0; x < size; x++) {
                 row[x] = str->getChar() ^ invert_bits;
-            if (writer)
+            }
+            if (writer) {
                 writer->writeRow(&row);
+            }
             break;
         }
     }
@@ -544,8 +562,9 @@ void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str, int w
                 return;
             }
             globalsStr->reset();
-            while ((c = globalsStr->getChar()) != EOF)
+            while ((c = globalsStr->getChar()) != EOF) {
                 fputc(c, f);
+            }
             globalsStr->close();
             fclose(f);
         }
@@ -562,24 +581,27 @@ void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str, int w
             error(errIO, -1, "Couldn't open image file '{0:s}'", fileName);
             return;
         }
-        if (ccittStr->getEncoding() < 0)
+        if (ccittStr->getEncoding() < 0) {
             fprintf(f, "-4 ");
-        else if (ccittStr->getEncoding() == 0)
+        } else if (ccittStr->getEncoding() == 0) {
             fprintf(f, "-1 ");
-        else
+        } else {
             fprintf(f, "-2 ");
+        }
 
-        if (ccittStr->getEndOfLine())
+        if (ccittStr->getEndOfLine()) {
             fprintf(f, "-A ");
-        else
+        } else {
             fprintf(f, "-P ");
+        }
 
         fprintf(f, "-X %d ", ccittStr->getColumns());
 
-        if (ccittStr->getBlackIs1())
+        if (ccittStr->getBlackIs1()) {
             fprintf(f, "-W ");
-        else
+        } else {
             fprintf(f, "-B ");
+        }
 
         fprintf(f, "-M\n"); // PDF uses MSB first
 
@@ -658,8 +680,9 @@ void ImageOutputDev::writeImage(GfxState *state, Object *ref, Stream *str, int w
         delete writer;
     }
 
-    if (inlineImg)
+    if (inlineImg) {
         embedStr->restore();
+    }
 }
 
 bool ImageOutputDev::tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, GfxTilingPattern *tPat, const double *mat, int x0, int y0, int x1, int y1, double xStep, double yStep)
@@ -670,18 +693,20 @@ bool ImageOutputDev::tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat,
 
 void ImageOutputDev::drawImageMask(GfxState *state, Object *ref, Stream *str, int width, int height, bool invert, bool interpolate, bool inlineImg)
 {
-    if (listImages)
+    if (listImages) {
         listImage(state, ref, str, width, height, nullptr, interpolate, inlineImg, imgStencil);
-    else
+    } else {
         writeImage(state, ref, str, width, height, nullptr, inlineImg);
+    }
 }
 
 void ImageOutputDev::drawImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, const int *maskColors, bool inlineImg)
 {
-    if (listImages)
+    if (listImages) {
         listImage(state, ref, str, width, height, colorMap, interpolate, inlineImg, imgImage);
-    else
+    } else {
         writeImage(state, ref, str, width, height, colorMap, inlineImg);
+    }
 }
 
 void ImageOutputDev::drawMaskedImage(GfxState *state, Object *ref, Stream *str, int width, int height, GfxImageColorMap *colorMap, bool interpolate, Stream *maskStr, int maskWidth, int maskHeight, bool maskInvert, bool maskInterpolate)
