@@ -17,6 +17,7 @@
 // Copyright 2021 Georgiy Sgibnev <georgiy@sgibnev.com>. Work sponsored by lab50.net.
 // Copyright 2021 Theofilos Intzoglou <int.teo@gmail.com>
 // Copyright 2022 Felix Jung <fxjung@posteo.de>
+// Copyright 2022 Erich E. Hoover <erich.e.hoover@gmail.com>
 //
 //========================================================================
 
@@ -116,14 +117,12 @@ static bool dumpSignature(int sig_num, int sigCount, FormFieldSignature *s, cons
     // We want format to be {0:s}.sig{1:Xd} where X is sigCountLength
     // since { is the magic character to replace things we need to put it twice where
     // we don't want it to be replaced
-    GooString *format = GooString::format("{{0:s}}.sig{{1:{0:d}d}}", sigCountLength);
-    GooString *path = GooString::format(format->c_str(), gbasename(filename).c_str(), sig_num);
+    const std::unique_ptr<GooString> format = GooString::format("{{0:s}}.sig{{1:{0:d}d}}", sigCountLength);
+    const std::unique_ptr<GooString> path = GooString::format(format->c_str(), gbasename(filename).c_str(), sig_num);
     printf("Signature #%d (%u bytes) => %s\n", sig_num, signature->getLength(), path->c_str());
     std::ofstream outfile(path->c_str(), std::ofstream::binary);
     outfile.write(signature->c_str(), signature->getLength());
     outfile.close();
-    delete format;
-    delete path;
 
     return true;
 }
@@ -138,7 +137,7 @@ static bool dontVerifyCert = false;
 static bool noOCSPRevocationCheck = false;
 static bool dumpSignatures = false;
 static bool etsiCAdESdetached = false;
-static int signatureNumber = 0;
+static char signatureName[256] = "";
 static char certNickname[256] = "";
 static char password[256] = "";
 static char digestName[256] = "SHA256";
@@ -156,7 +155,7 @@ static const ArgDesc argDesc[] = { { "-nssdir", argGooString, &nssDir, 0, "path
                                    { "-dump", argFlag, &dumpSignatures, 0, "dump all signatures into current directory" },
                                    { "-add-signature", argFlag, &addNewSignature, 0, "adds a new signature to the document" },
                                    { "-new-signature-field-name", argGooString, &newSignatureFieldName, 0, "field name used for the newly added signature. A random ID will be used if empty" },
-                                   { "-sign", argInt, &signatureNumber, 0, "sign the document in the signature field with the given number" },
+                                   { "-sign", argString, &signatureName, 256, "sign the document in the given signature field (by name or number)" },
                                    { "-etsi", argFlag, &etsiCAdESdetached, 0, "create a signature of type ETSI.CAdES.detached instead of adbe.pkcs7.detached" },
                                    { "-nick", argString, &certNickname, 256, "use the certificate with the given nickname for signing" },
                                    { "-kpw", argString, &password, 256, "password for the signing key (might be missing if the key isn't password protected)" },
@@ -219,6 +218,24 @@ static std::vector<std::unique_ptr<X509CertificateInfo>> getAvailableSigningCert
     return vCerts;
 }
 
+static std::string TextStringToUTF8(const std::string &str)
+{
+    const UnicodeMap *utf8Map = globalParams->getUtf8Map();
+
+    Unicode *u;
+    const int len = TextStringToUCS4(str, &u);
+
+    std::string convertedStr;
+    for (int i = 0; i < len; ++i) {
+        char buf[8];
+        const int n = utf8Map->mapUnicode(u[i], buf, sizeof(buf));
+        convertedStr.append(buf, n);
+    }
+    gfree(u);
+
+    return convertedStr;
+}
+
 int main(int argc, char *argv[])
 {
     char *time_str = nullptr;
@@ -272,20 +289,30 @@ int main(int argc, char *argv[])
 
     std::unique_ptr<GooString> fileName = std::make_unique<GooString>(argv[1]);
 
-    std::unique_ptr<GooString> ownerPW, userPW;
+    std::optional<GooString> ownerPW, userPW;
     if (ownerPassword[0] != '\001') {
-        ownerPW = std::make_unique<GooString>(ownerPassword);
+        ownerPW = GooString(ownerPassword);
     }
     if (userPassword[0] != '\001') {
-        userPW = std::make_unique<GooString>(userPassword);
+        userPW = GooString(userPassword);
     }
     // open PDF file
-    std::unique_ptr<PDFDoc> doc(PDFDocFactory().createPDFDoc(*fileName, ownerPW.get(), userPW.get()));
+    std::unique_ptr<PDFDoc> doc(PDFDocFactory().createPDFDoc(*fileName, ownerPW, userPW));
 
     if (!doc->isOk()) {
         return 1;
     }
 
+    int signatureNumber;
+    if (strlen(signatureName) > 0) {
+        signatureNumber = atoi(signatureName);
+        if (signatureNumber == 0) {
+            signatureNumber = -1;
+        }
+    } else {
+        signatureNumber = 0;
+    }
+
     if (addNewSignature && signatureNumber > 0) {
         // incompatible options
         print_version_usage(true);
@@ -345,13 +372,33 @@ int main(int argc, char *argv[])
         // We don't provide a way to customize the UI from pdfsig for now
         const bool success = doc->sign(argv[2], certNickname, pw, newSignatureFieldName.copy(), /*page*/ 1,
                                        /*rect */ { 0, 0, 0, 0 }, /*signatureText*/ {}, /*signatureTextLeft*/ {}, /*fontSize */ 0, /*leftFontSize*/ 0,
-                                       /*fontColor*/ {}, /*borderWidth*/ 0, /*borderColor*/ {}, /*backgroundColor*/ {}, rs.get(), /* location */ nullptr, /* image path */ "", ownerPW.get(), userPW.get());
+                                       /*fontColor*/ {}, /*borderWidth*/ 0, /*borderColor*/ {}, /*backgroundColor*/ {}, rs.get(), /* location */ nullptr, /* image path */ "", ownerPW, userPW);
         return success ? 0 : 3;
     }
 
     const std::vector<FormFieldSignature *> signatures = doc->getSignatureFields();
     const unsigned int sigCount = signatures.size();
 
+    if (signatureNumber == -1) {
+        for (unsigned int i = 0; i < sigCount; i++) {
+            const GooString *goo = signatures.at(i)->getCreateWidget()->getField()->getFullyQualifiedName();
+            if (!goo) {
+                continue;
+            }
+
+            const std::string name = TextStringToUTF8(goo->toStr());
+            if (name == signatureName) {
+                signatureNumber = i + 1;
+                break;
+            }
+        }
+
+        if (signatureNumber == -1) {
+            fprintf(stderr, "Signature field not found by name\n");
+            return 2;
+        }
+    }
+
     if (signatureNumber > 0) {
         // We are signing an existing signature field
         if (argc == 2) {
@@ -383,8 +430,9 @@ int main(int argc, char *argv[])
             printf("Signature number %d is already signed\n", signatureNumber);
             return 2;
         }
-        if (etsiCAdESdetached)
+        if (etsiCAdESdetached) {
             ffs->setSignatureType(ETSI_CAdES_detached);
+        }
         const char *pw = (strlen(password) == 0) ? nullptr : password;
         const auto rs = std::unique_ptr<GooString>(reason.toStr().empty() ? nullptr : utf8ToUtf16WithBom(reason.toStr()));
         if (ffs->getNumWidgets() != 1) {
@@ -423,6 +471,11 @@ int main(int argc, char *argv[])
     for (unsigned int i = 0; i < sigCount; i++) {
         FormFieldSignature *ffs = signatures.at(i);
         printf("Signature #%u:\n", i + 1);
+        const GooString *goo = ffs->getCreateWidget()->getField()->getFullyQualifiedName();
+        if (goo) {
+            const std::string name = TextStringToUTF8(goo->toStr());
+            printf("  - Signature Field Name: %s\n", name.c_str());
+        }
 
         if (ffs->getSignatureType() == unsigned_signature_field) {
             printf("  The signature form field is not signed.\n");
